<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>InsertScriptItem</name>
    <message>
        <source>Insert Script</source>
        <translation type="obsolete">Insérer un script</translation>
    </message>
    <message>
        <source>Position</source>
        <translation type="vanished">Position</translation>
    </message>
    <message>
        <location filename="../InsertScriptItemInit.js" line="+2"/>
        <source>Insert &amp;Script</source>
        <translation>Insérer un &amp;script</translation>
    </message>
</context>
</TS>
